Abstract Base Classes
=====================

.. currentmodule:: fastobo.abc
.. automodule:: fastobo.abc

Frame
-----

.. autoclass:: AbstractFrame(collections.abc.MutableSeq)
   :members:
   :special-members:

.. autoclass:: AbstractEntityFrame(AbstractFrame)
   :members:
   :special-members:


Clauses
-------

.. autoclass:: AbstractClause
   :members:
   :special-members:

.. autoclass:: AbstractEntityClause(AbstractClause)
   :members:
   :special-members:
